.. _api-dao:

=========================
Data Access Objects (DAO)
=========================

.. _api-dao-class:

.. autoclass:: protean.port.dao.BaseDAO

.. _api-dao-create:

``create()``
^^^^^^^^^^^^

.. automethod:: protean.port.dao.BaseDAO.create

.. _api-dao-save:

``save()``
^^^^^^^^^^^^

.. automethod:: protean.port.dao.BaseDAO.save

.. _api-dao-update:

``update()``
^^^^^^^^^^^^

.. automethod:: protean.port.dao.BaseDAO.update

.. _api-dao-get:

``get()``
^^^^^^^^^^^^

.. automethod:: protean.port.dao.BaseDAO.get

.. _api-dao-find-by:

``find_by()``
^^^^^^^^^^^^^

.. automethod:: protean.port.dao.BaseDAO.find_by

.. _api-dao-exists:

``exists()``
^^^^^^^^^^^^

.. automethod:: protean.port.dao.BaseDAO.exists

.. _api-dao-delete:

``delete()``
^^^^^^^^^^^^

.. automethod:: protean.port.dao.BaseDAO.delete

.. _api-dao-delete-all:

``delete_all()``
^^^^^^^^^^^^^^^^

.. automethod:: protean.port.dao.BaseDAO.delete_all
